==> HFRCerveau_0.2.0.tgz: HFRCerveau/emoticons.py <==
emoticons = {
':)': 'Smile.png',
':-)': 'Smile.png',
':D': 'D.png',
';)': 'Wink.png',
';o)': 'Wink.png',
';-)': 'Wink.png',
':(': 'Sad.png',
':/': 'Erf.png',
':p': 'Tongue.png',
':P': 'Tongue.png',
':o': 'O.png',
':??:': 'Confused.png',
':sweat:': 'Sweat.png',
':mmmfff:': 'Mmmfff.png',
':sol:': 'Sol.png',
':dawa:': 'Dawa.png',
':god:': 'God.png',
':love:': 'Love.png',
':boidleau:': 'Boidleau.png',
':chacal_one333:': 'Chacal_One333.png',
':autobot:': 'Autobot.png',
':cupra:': 'Cupra.png',
':ddr555:': 'Ddr555.png',
':fou:': 'Fou.png',
':fuck:': 'Fuck.png',
':kneu:': 'Kneu.png',
':mlc:': 'Mlc.png',
':ouch:': 'Ouch.png',
':pingouino:': 'Pingouino.png',
':kiki:': 'Kiki.png',
':huit:': 'Huit.png',
':neuf:': 'Neuf.png',
':tinostar:': 'Tinostar.png',
':haha:': 'Haha.png',
':petrus75:': 'Petrus.png',
':shay:': 'Shay.png',
':ciler:': 'Ciler.png',
':tt:': 'TT.png',
':vomi:': 'Vomi.png',
':drapal:': 'Drapal.png',
':boulay:': 'Boulay.png',
':thalis:': 'Thalis.png',
':afrojojo:': 'Afrojojo.png',
':aloy:': 'Aloy.png',
':ban:': 'Ban.png',
':pouah:': 'Pouah.png',
':nico54:': 'Nico54.png',
':yvele:': 'Yvele.png',
':joce:': 'Joce.png',
':popcorn:': 'Popcorn.png',
':x': 'Shut.png',
':neriki:': 'Neriki.png',
':cry:': 'Cry.gif',
':lol:': 'Lol.gif',
':whistle:': 'Whistle.gif',
':heink:': 'Heink.gif',
':jap:': 'Jap.gif',
':sleep:': 'Sleep.gif',
':pt1cable:': 'Pt1Cable.gif',
':arn0:': 'Arn0.gif',
':spamafote:': 'SpaMaFote.gif',
':eonwe:': 'Eonwe.gif',
':delight:': 'Delight.gif',
':violon:': 'Violon.gif',
':zebra33:': 'Zebra.gif',
':discobeck:': 'Discobeck.gif',
':bounce:': 'Bounce.gif',
':merdocu:': 'Merdocu.gif',
':zoubi:': 'Zoubi.gif',
':wam:': 'Wam.gif',
':branlette:': 'Branlette.gif',
':elmoricq:': 'Elmoricq.gif',
':roi:': 'Roi.gif',
':kahn21:': 'Kahn21.gif',
':adodonicoco:': 'Adodonicoco.gif',
':totoz:': 'Totoz.gif',
':prodigy:': 'Prodigy.png',
':makokotte:': 'Makokotte.gif',
':rofl:': 'Rofl.gif',
':simchevelu:': 'Simchevelu.gif',
}

==> HFRCerveau_0.3.0.tgz: HFRCerveau/emoticons.py <==
emoticons = {
':)': 'Smile.png',
':-)': 'Smile.png',
':D': 'D.png',
';)': 'Wink.png',
';o)': 'Wink.png',
';-)': 'Wink.png',
':(': 'Sad.png',
':/': 'Erf.png',
':p': 'Tongue.png',
':P': 'Tongue.png',
':o': 'O.png',
':??:': 'Confused.png',
':sweat:': 'Sweat.png',
':mmmfff:': 'Mmmfff.png',
':sol:': 'Sol.png',
':dawa:': 'Dawa.png',
':god:': 'God.png',
':love:': 'Love.png',
':boidleau:': 'Boidleau.png',
':chacal_one333:': 'Chacal_One333.png',
':autobot:': 'Autobot.png',
':cupra:': 'Cupra.png',
':ddr555:': 'Ddr555.png',
':fou:': 'Fou.png',
':fuck:': 'Fuck.png',
':kneu:': 'Kneu.png',
':mlc:': 'Mlc.png',
':ouch:': 'Ouch.png',
':pingouino:': 'Pingouino.png',
':kiki:': 'Kiki.png',
':huit:': 'Huit.png',
':neuf:': 'Neuf.png',
':tinostar:': 'Tinostar.png',
':haha:': 'Haha.png',
':hahaguy:': 'Hahaguy.png',
':petrus75:': 'Petrus.png',
':shay:': 'Shay.png',
':ciler:': 'Ciler.png',
':tt:': 'TT.png',
':vomi:': 'Vomi.gif',
':drapal:': 'Drapal.png',
':+1:': '+1.png',
':boulay:': 'Boulay.png',
':thalis:': 'Thalis.png',
':afrojojo:': 'Afrojojo.png',
':aloy:': 'Aloy.png',
':ban:': 'Ban.png',
':pouah:': 'Pouah.png',
':nico54:': 'Nico54.png',
':yvele:': 'Yvele.png',
':joce:': 'Joce.png',
':popcorn:': 'Popcorn.png',
':x': 'Shut.png',
':neriki:': 'Neriki.png',
':cry:': 'Cry.gif',
':lol:': 'Lol.gif',
':whistle:': 'Whistle.gif',
':heink:': 'Heink.gif',
':jap:': 'Jap.gif',
':sleep:': 'Sleep.gif',
':pt1cable:': 'Pt1Cable.gif',
':arn0:': 'Arn0.gif',
':spamafote:': 'SpaMaFote.gif',
':eonwe:': 'Eonwe.gif',
':delight:': 'Delight.gif',
':violon:': 'Violon.gif',
':zebra33:': 'Zebra.gif',
':discobeck:': 'Discobeck.gif',
':bounce:': 'Bounce.gif',
':merdocu:': 'Merdocu.gif',
':zoubi:': 'Zoubi.gif',
':wam:': 'Wam.gif',
':branlette:': 'Branlette.gif',
':elmoricq:': 'Elmoricq.gif',
':roi:': 'Roi.gif',
':kahn21:': 'Kahn21.gif',
':adodonicoco:': 'Adodonicoco.gif',
':totoz:': 'Totoz.gif',
':prodigy:': 'Prodigy.png',
':makokotte:': 'Makokotte.gif',
':rofl:': 'Rofl.gif',
':simchevelu:': 'Simchevelu.gif',
':bernadette:': 'Bernadette.png',
':sisicaivrai:': 'Sisicaivrai.gif',
':perchut2:': 'Perchut2.gif',
':obawi:': 'Obawi.gif',
':kukron:': 'Kukron.gif',
':skyzor:': 'Skyzor.gif',
':atsuko:': 'Atsuko.gif',
':zeusy:' : 'Zeusy.png',
':dawacube:' : 'Dawacube.gif',
}
